@@ -25,7 +25,7 @@
 **  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 **  SUCH DAMAGE.
 **
-**  tai_lib.c: API implementation
+**  tm.c: API implementation
 */
 
 #include <stdio.h>
@@ -37,6 +37,26 @@
 #include "tai.h"
 #include "tai_p.h"
 
+struct tai_st {
+    int    tai_sec;    /* seconds after the minute [0-61] */
+    int    tai_min;    /* minutes after the hour [0-59] */
+    int    tai_hour;   /* hours since midnight [0-23] */
+    int    tai_mday;   /* day of the month [1-31] */
+    int    tai_mon;    /* months since January [0-11] */
+    int    tai_year;   /* years since 1900 */
+    int    tai_wday;   /* days since Sunday [0-6] */
+    int    tai_yday;   /* days since January 1 [0-365] */
+    int    tai_isdst;  /* Daylight Savings Time flag */
+    long   tai_gmtoff; /* offset from CUT in seconds */
+    char  *tai_zone;   /* timezone abbreviation */
+#if 0
+    int sign;
+    unsigned long long sec;
+    unsigned long nsec;
+    unsigned long asec;
+#endif
+};
+
 tai_rc_t tai_create(tai_t **ptai)
 {
     tai_t *tai;
@@ -56,40 +76,12 @@ tai_rc_t tai_destroy(tai_t *tai)
 {
     if (tai == NULL)
         return TAI_ERR_ARG;
+    if (tai->tai_zone != NULL)
+        free(tai->tai_zone);
     free(tai);
     return TAI_OK;
 }
 
-#if 0
-static time_t tai_utcoffset(void)
-{
-    time_t tL, tU;
-    struct tm *tmL, *tmU;
-    time_t offset;
-
-    /* determine local time (UTC based) */
-    tL = time(NULL); /* theoretically this could be a constant value, too */
-
-    /* unpack local time (local time based) */
-    tmL = localtime(&tL);
-
-    /* unpack local time (UTC based) */
-    tmU = gmtime(&tL);
-
-    /* pack UTC-based local time back into local time */
-    tU  = mktime(tmU);
-
-    /* local time adjustment for Daylight Saving Time (DST) */
-    if (tmL->tm_isdst)
-        tL += (60*60);
-
-    /* finally calculate the UTC offset */
-    offset = (tL - tU);
-
-    return offset;
-}
-#endif
-
 tai_rc_t tai_import(tai_t *tai, tai_type_t type, ...)
 {
     va_list ap;
@@ -119,11 +111,11 @@ tai_rc_t tai_import(tai_t *tai, tai_type_t type, ...)
         tai->tai_wday   = stm->tm_wday;
         tai->tai_yday   = stm->tm_yday;
         tai->tai_isdst  = stm->tm_isdst;
-#ifdef HAVE_TM_GMTOFF
-        tai->tai_gmtoff = stm->tm_gmtoff; /* implicitly 0 */
-#else
-        tai->tai_gmtoff = 0;              /* explicitly 0 */
-#endif
+        tai->tai_gmtoff = stm->tm_gmtoff;
+        if (stm->tm_zone == NULL)
+            tai->tai_zone = strdup("");
+        else
+            tai->tai_zone = strdup(stm->tm_zone);
     }
     else if (type == TAI_TYPE_STRUCTTM) {
         /* import from struct tm */
@@ -149,18 +141,11 @@ tai_rc_t tai_import(tai_t *tai, tai_type_t type, ...)
         tai->tai_wday   = stm->tm_wday;
         tai->tai_yday   = stm->tm_yday;
         tai->tai_isdst  = stm->tm_isdst;
-#ifdef HAVE_TM_GMTOFF
         tai->tai_gmtoff = stm->tm_gmtoff;
-#else
-        tai->tai_gmtoff = 0;
-#endif
-    }
-    else if (type == TAI_TYPE_UNIX) {
-        /* import from time(3) FIXME */
-        time_t t = time(NULL);
-        tai->sec  = tai_ui64_n2i((unsigned long)t);
-        tai->asec = tai_ui64_n2i((unsigned long)0);
-        tai_tai2cal(tai, 7200);
+        if (stm->tm_zone == NULL)
+            tai->tai_zone = strdup("");
+        else
+            tai->tai_zone = strdup(stm->tm_zone);
     }
     else
         return TAI_ERR_IMP; /* FIXME */
@@ -193,9 +178,8 @@ tai_rc_t tai_export(tai_t *tai, tai_type_t type, ...)
         stm->tm_wday   = tai->tai_wday;
         stm->tm_yday   = tai->tai_yday;
         stm->tm_isdst  = tai->tai_isdst;
-#ifdef HAVE_TM_GMTOFF
         stm->tm_gmtoff = tai->tai_gmtoff;
-#endif
+        stm->tm_zone   = tai->tai_zone;
 #ifdef HAVE_TIMEGM
         /* non-standard timegm(3) makes our life easy */
         *pt = timegm(stm);
@@ -220,9 +204,8 @@ tai_rc_t tai_export(tai_t *tai, tai_type_t type, ...)
         stm->tm_wday   = tai->tai_wday;
         stm->tm_yday   = tai->tai_yday;
         stm->tm_isdst  = tai->tai_isdst;
-#ifdef HAVE_TM_GMTOFF
         stm->tm_gmtoff = tai->tai_gmtoff;
-#endif
+        stm->tm_zone   = strdup(tai->tai_zone);
     }
     else
         return TAI_ERR_IMP; /* FIXME */
@@ -267,32 +250,3 @@ tai_rc_t tai_parse(tai_t *tai, const char *buf_ptr, size_t buf_len, const char *
     return TAI_OK;
 }
 
-tai_rc_t tai_op(tai_t *tai, tai_op_t op, ...)
-{
-    tai_rc_t rc = TAI_ERR_IMP;
-    va_list ap;
-
-    if (tai == NULL)
-        return TAI_ERR_ARG;
-    va_start(ap, op); 
-    if ((op == TAI_OP_NE) || (op == TAI_OP_EQ) || (op == TAI_OP_LT) || (op == TAI_OP_LE) || (op == TAI_OP_GT) || (op == TAI_OP_GE)) {
-        tai_t *tai1, *tai2;
-        unsigned long s1, s2;
-
-        tai1 = tai;
-        tai2 = (tai_t *)va_arg(ap, void *);
-        s1 = tai1->tai_sec + (60 * tai1->tai_min) + (60 * 60 * tai1->tai_hour) + (60 * 60 * 24 * tai1->tai_yday) + (60 * 60 * 24 * 365 * tai1->tai_year) + tai1->tai_gmtoff;
-        s2 = tai2->tai_sec + (60 * tai2->tai_min) + (60 * 60 * tai2->tai_hour) + (60 * 60 * 24 * tai2->tai_yday) + (60 * 60 * 24 * 365 * tai2->tai_year) + tai2->tai_gmtoff;
-        switch (op) {
-            case TAI_OP_NE: rc = (s2 != s1 ? TAI_OK : TAI_FALSE); break;
-            case TAI_OP_EQ: rc = (s2 == s1 ? TAI_OK : TAI_FALSE); break;
-            case TAI_OP_LT: rc = (s2 <  s1 ? TAI_OK : TAI_FALSE); break;
-            case TAI_OP_LE: rc = (s2 <= s1 ? TAI_OK : TAI_FALSE); break;
-            case TAI_OP_GT: rc = (s2 >  s1 ? TAI_OK : TAI_FALSE); break;
-            case TAI_OP_GE: rc = (s2 >= s1 ? TAI_OK : TAI_FALSE); break;
-            default: break; /* FIXME */
-        }
-    }
-    va_end(ap); 
-    return rc;
-}
