@@ -1,8 +1,8 @@
 /*
 **  OSSP var - Variable Expansion
-**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2004 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2001-2004 Cable & Wireless (http://www.cw.com/)
+**  Copyright (c) 2001-2005 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2005 The OSSP Project (http://www.ossp.org/)
+**  Copyright (c) 2001-2005 Cable & Wireless (http://www.cw.com/)
 **
 **  This file is part of OSSP var, a variable expansion
 **  library which can be found at http://www.ossp.org/pkg/lib/var/.
@@ -32,6 +32,7 @@
 #include "config.h"
 #endif
 
+/* required system headers */
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
@@ -44,11 +45,13 @@
 #else
 #  include <regex.h>
 #endif
-#include "var.h"
 #if defined(HAVE_DMALLOC_H) && defined(WITH_DMALLOC)
-#include "dmalloc.h"
+#include <dmalloc.h>
 #endif
 
+/* required internal headers */
+#include "var.h"
+
 /* unique library identifier */
 const char var_id[] = "OSSP var";
 
@@ -2537,6 +2540,7 @@ var_unescape(
                             return VAR_RC(rc);
                         break;
                     }
+                    /* FALLTHROUGH */
                 default:
                     if (!all) {
                         *dst++ = '\\';
@@ -2719,7 +2723,7 @@ static const char *var_errors[] = {
     "formatting failure"                                       /* VAR_ERR_FORMATTING_FAILURE */
 };
 
-/* transslate a return code into its corresponding descriptive text */
+/* translate a return code into its corresponding descriptive text */
 var_rc_t var_strerror(var_t *var, var_rc_t rc, char **str)
 {
     if (str == NULL)
